# Cbers4asat

Biblioteca Python para consultar o catálogo e realizar operações com dados do CBERS4A e AMAZONIA1.

## Descrição do projeto

A biblioteca `cbers4asat` surgiu da necessidade de automatizar a busca e manipulação de imagens do satélite
sino-brasileiro CBERS-04A utilizando linguagens de programação.

O design do projeto foi inspirado no [sentinelsat](https://github.com/sentinelsat/sentinelsat), onde é possível de forma
intuitiva, pesquisar por imagens e realizar o download com poucas linhas de código, além de poder ser integrado com
outras bibiliotecas como o geopandas.

A base de dados que está sendo utilizada pertence a Divisão de Geração de Imagens do Instituto Nacional de Pesquisa
Especial (INPE). E sendo consumida através da aplicação REST
API [SpatioTemporal Asset Catalogs](https://stacspec.org/en/).

## Sumário

* [Instalação](installation.md)
* [Guia de usuário](quickstart.md)
* [Documentação](api_reference.md)
* [Exemplos básicos](examples.md)
